==> tine20-allinone_2020.08.8.tar.bz2: Setup/js/Setup-lang-pl-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nLanguage: pl\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "Przeczytałem postanowienia licencji i je akceptuję"

, "License Agreement"
: "Warunki udzielenia licencji"

, "I have read the privacy agreement and accept it"
: "Przeczytałem postanowienia poufności i je akceptuję"

, "Privacy Agreement"
: "Postanowienia poufności"

, "Accept Terms and Conditions"
: "Akceptuję warunki i postanowienia."

, "Backend"
: "Backend"

, "Standard IMAP"
: "IMAP"

, "Standard SMTP"
: "SMTP"

, "Imap"
: "IMAP"

, "Hostname"
: "Komputer"

, "Username"
: "Użytkownik"

, "Password"
: "Hasło"

, "Port"
: "Port"

, "Secure Connection"
: "Bezpieczne połączenie"

, "None"
: "Brak"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Użyj konta systemowego"

, "No"
: "Nie"

, "Yes"
: "Tak"

, "Append domain to login name"
: "Dołącz domenę do loginu"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Administrator - Cyrus"

, "Cyrus Admin Password"
: "Hasło adminitratora - Cyrus"

, "Use proxy auth"
: ""

, "Smtp"
: "SMTP"

, "Authentication"
: "Uwierzytelnienie"

, "Login"
: "Login"

, "Plain"
: "Czysty tekst"

, "Primary Domain"
: "Domena główna"

, "Secondary Domains (comma separated)"
: "Poddomeny (oddzielone przecinkiem)"

, "Notifications service address"
: "Adres e-mail usługi powiadamiania"

, "Notification Username"
: "Przypomnienie nazwy użytkownika"

, "Notification Password"
: "Przypomnienie hasła"

, "Notifications local client (hostname or IP address)"
: "Powiadomienia, klient lokalny (nazwa hosta albo adres IP)"

, "SIEVE"
: "FILTR"

, "MySql Hostname"
: "Nazwa hosta dla MySQL"

, "MySql Database"
: "Baza danych MySQL"

, "MySql User"
: "Użytkownik MySQL"

, "MySql Password"
: "Hasło dla MySQL"

, "MySql Port"
: "Port MySQL"

, "User or UID"
: "Użytkownik albo UID"

, "Group or GID"
: "Grupa albo GID"

, "Home Template"
: "Szablon strony domowej"

, "Password Scheme"
: "Schemat hasła"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SHAA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SHAA512"

, "PLAIN"
: "PLAIN"

, "Terms and Conditions"
: "Warunki i postanowienia"

, "Setup Checks"
: "Testy konfiguracji"

, "Config Manager"
: "Konfigurator ustawień"

, "Authentication/Accounts"
: "Uwierzytelnienie / Konta"

, "Email"
: "E-mail"

, "Application Manager"
: "Konfigurator aplikacji"

, "Setup"
: ""

, "Name"
: "Nazwa"

, "Enabled"
: "Włączona"

, "Order"
: "Kolejność"

, "Installed Version"
: "Zainstalowana wersja"

, "Available Version"
: "Dostępna wersja"

, "Status"
: "Status"

, "Depends on"
: "Zależy od"

, "Install application"
: "Zainstaluj aplikację"

, "Uninstall application"
: "Odinstaluj aplikację"

, "Update application"
: "Aktualizuj aplikację"

, "Go to {0} login"
: "Przejdź do logowania {0}"

, "uninstall"
: "odinstaluj"

, "Do you really want to uninstall the application(s)?"
: "Czy na pewno chcesz odinstalować aplikację?"

, "This may take a while"
: "To może chwilę potrwać"

, "Dependency Violation"
: "Niespełnione zależności"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Usuń wszystkich, istniejących użytkowników i grupy"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Przejście z SQL na LDAP usunie wszystkie, istniejące konta użytkowników, grupy oraz role. Czy na pewno chcesz przełączyć konta na LDAP?"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Początkowy administrator"

, "Initial admin login name"
: "Początkowy login administratora"

, "Initial admin Password"
: "Początkowe hasło administratora"

, "Password confirmation"
: "Potwierdzenie hasła"

, "Authentication provider"
: "Uwierzytelnienie"

, "Try to split username"
: "Spróbuj podzielić nazwę użytkownika"

, "Account canonical form"
: "Konto standardowe"

, "Account domain name"
: ""

, "Account domain short name"
: "Skrót nazwy domeny konta"

, "Host"
: "Komputer"

, "Login name"
: "Login"

, "Bind requires DN"
: "Bind wymaga nazwy domeny"

, "Start TLS"
: ""

, "Base DN"
: "Podstawowa domena"

, "Search filter"
: "Filtr wyszukiwania"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Konta"

, "Default user group name"
: "Domyślna nazwa grupy użytkownika"

, "Default admin group name"
: "Domyślna nazwa grupy administratora"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: "Ustawienia hasła"

, "User can change password"
: "Użytkownik może zmienić hasło"

, "Enable password policy"
: "Włącz politykę haseł"

, "Only ASCII"
: "Wyłącznie znaki ASCII"

, "Minimum length"
: "Minimalna długość"

, "Minimum word chars"
: "Minimalna ilość znaków w słowie"

, "Minimum uppercase chars"
: "Minimalna ilość wielkich liter"

, "Minimum special chars"
: "Minimalna ilość znaków specjalnych"

, "Minimum numbers"
: "Minimalna ilość cyfr"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Zabroń używania części nazwy użytkownika w haśle"

, "Redirect Settings"
: "Ustawienia przekierowania"

, "Redirect Url (redirect to login screen if empty)"
: "Przekieruj URL (jeśli pusty, wyświetl ekran logowania)"

, "Redirect Always (if No, only redirect after logout)"
: "Zawsze przekieruj (w przypadku Nie, przekieruj po wylogowaniu)"

, "Redirect to referring site, if exists"
: "Przekieruj do powiązanej strony, jeśli istnieje"

, "Password encoding"
: "Metoda kodowania hasła"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "Domena użytkownika"

, "User Filter"
: "Filtr użytkowników"

, "User Search Scope"
: "Zakres wyszukiwania użytkowników"

, "Groups DN"
: "Domena grupy"

, "Group Filter"
: "Filtr grupy"

, "Group Search Scope"
: "Zakres wyszukiwania grupy"

, "Use Rfc 2307 bis"
: "Stosuj RFC 2307 aż do"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Min. id użytkownika"

, "Max User Id"
: "Maks. id użytkownika"

, "Min Group Id"
: "Min. id grupy"

, "Max Group Id"
: "Maks. id grupy"

, "Group UUID Attribute name"
: "Unikalny atrybut grupy"

, "User UUID Attribute name"
: "Unikalny atrybut użytkownika"

, "Readonly access"
: "Tylko do odczytu"

, "Save config and install"
: "Zapisz konfigurację i zainstaluj"

, "Save config"
: "Zapisz konfigurację"

, "Passwords don't match"
: "Hasła nie są takie same"

, "Should not be empty"
: "Nie może być puste"

, "Performing Environment Checks..."
: "Przygotowywanie testów środowiska..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Nie znaleziono {0}. Proszę spróbować zmienić kryteria filtrowania, opcje podglądu albo {1}, w którym szukasz."

, "Check"
: "Sprawdzane składniki"

, "Result"
: "Wynik"

, "Error"
: "Błąd"

, "Run setup tests"
: "Uruchom testy konfiguracji"

, "Ignore setup tests"
: "Ignoruj testy ustawień"

, "Application, Applications"
: [
  "Aplikacja"
 ,"aplikacje"
 ,"aplikacje"
 ,"aplikacje"

]
, "File"
: "Plik"

, "Setup Authentication"
: "Konfiguruj uwierzytelnianie"

, "Database"
: "Baza danych"

, "User"
: "Użytkownik"

, "Prefix"
: "Przedrostek"

, "Logging"
: "Logi"

, "Filename"
: "Zapisuj do pliku"

, "Priority"
: "Tryb zapisu"

, "Caching"
: "Włącz pamięć podręczną"

, "Lifetime (seconds)"
: "Czas życia (sekundy)"

, "Path"
: "Ścieżka"

, "Queue"
: "Kolejka"

, "Session"
: "Sesja"

, "Temporary files"
: "Pliki tymczasowe"

, "Temporary Files Path"
: "Ścieżka do plików tymczasowych"

, "Filestore directory"
: "Katalog plików"

, "Filestore Path"
: "Ścieżka do katalogu plików"

, "Addressbook Map panel"
: "Mapowanie książki adresowej"

, "Map panel"
: "Mapowanie"

, "disabled"
: "wyłączone"

, "enabled"
: "włączone"

, "Config file is not writable"
: "Brak uprawnień zapisu do pliku konfiguracyjnego"

, "Download config file"
: "Pobierz plik konfiguracyjny"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Aplikacja"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Setup/js/Setup-lang-pl-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nLanguage: pl\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Performing Environment Checks..."
: "Przygotowywanie testów środowiska..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Nie znaleziono {0}. Proszę spróbować zmienić kryteria filtrowania, opcje podglądu albo {1}, w którym szukasz."

, "Check"
: "Sprawdzane składniki"

, "Result"
: "Wynik"

, "Message"
: ""

, "Run setup tests"
: "Uruchom testy konfiguracji"

, "Ignore setup tests"
: "Ignoruj testy ustawień"

, "Install application"
: "Zainstaluj aplikację"

, "Name"
: "Nazwa"

, "Enabled"
: "Włączona"

, "Order"
: "Kolejność"

, "Installed Version"
: "Zainstalowana wersja"

, "Available Version"
: "Dostępna wersja"

, "Status"
: "Status"

, "Depends on"
: "Zależy od"

, "Uninstall application"
: "Odinstaluj aplikację"

, "Update applications"
: ""

, "Go to {0} login"
: "Przejdź do logowania {0}"

, "uninstall"
: "odinstaluj"

, "Do you really want to uninstall the application(s)?"
: "Czy na pewno chcesz odinstalować aplikację?"

, "This may take a while"
: "To może chwilę potrwać"

, "Dependency Violation"
: "Niespełnione zależności"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Usuń wszystkich, istniejących użytkowników i grupy"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Przejście z SQL na LDAP usunie wszystkie, istniejące konta użytkowników, grupy oraz role. Czy na pewno chcesz przełączyć konta na LDAP?"

, "Backend"
: "Backend"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Początkowy administrator"

, "Initial admin login name"
: "Początkowy login administratora"

, "Initial admin Password"
: "Początkowe hasło administratora"

, "Password confirmation"
: "Potwierdzenie hasła"

, "Authentication provider"
: "Uwierzytelnienie"

, "Try to split username"
: "Spróbuj podzielić nazwę użytkownika"

, "Yes"
: "Tak"

, "No"
: "Nie"

, "Account canonical form"
: "Konto standardowe"

, "Account domain name"
: ""

, "Account domain short name"
: "Skrót nazwy domeny konta"

, "Host"
: "Komputer"

, "Login name"
: "Login"

, "Password"
: "Hasło"

, "Bind requires DN"
: "Bind wymaga nazwy domeny"

, "Start TLS"
: ""

, "SSL"
: "SSL"

, "Port"
: "Port"

, "Base DN"
: "Podstawowa domena"

, "Search filter"
: "Filtr wyszukiwania"

, "Hostname"
: "Komputer"

, "Secure Connection"
: "Bezpieczne połączenie"

, "None"
: "Brak"

, "TLS"
: "TLS"

, "Append domain to login name"
: "Dołącz domenę do loginu"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Konta"

, "Default user group name"
: "Domyślna nazwa grupy użytkownika"

, "Default admin group name"
: "Domyślna nazwa grupy administratora"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: "Ustawienia hasła"

, "User can change password"
: "Użytkownik może zmienić hasło"

, "Enable password policy"
: "Włącz politykę haseł"

, "Only ASCII"
: "Wyłącznie znaki ASCII"

, "Minimum length"
: "Minimalna długość"

, "Minimum word chars"
: "Minimalna ilość znaków w słowie"

, "Minimum uppercase chars"
: "Minimalna ilość wielkich liter"

, "Minimum special chars"
: "Minimalna ilość znaków specjalnych"

, "Minimum numbers"
: "Minimalna ilość cyfr"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Zabroń używania części nazwy użytkownika w haśle"

, "Redirect Settings"
: "Ustawienia przekierowania"

, "Redirect Url (redirect to login screen if empty)"
: "Przekieruj URL (jeśli pusty, wyświetl ekran logowania)"

, "Redirect Always (if No, only redirect after logout)"
: "Zawsze przekieruj (w przypadku Nie, przekieruj po wylogowaniu)"

, "Redirect to referring site, if exists"
: "Przekieruj do powiązanej strony, jeśli istnieje"

, "Password encoding"
: "Metoda kodowania hasła"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "Domena użytkownika"

, "User Filter"
: "Filtr użytkowników"

, "User Search Scope"
: "Zakres wyszukiwania użytkowników"

, "Groups DN"
: "Domena grupy"

, "Group Filter"
: "Filtr grupy"

, "Group Search Scope"
: "Zakres wyszukiwania grupy"

, "Use Rfc 2307 bis"
: "Stosuj RFC 2307 aż do"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Min. id użytkownika"

, "Max User Id"
: "Maks. id użytkownika"

, "Min Group Id"
: "Min. id grupy"

, "Max Group Id"
: "Maks. id grupy"

, "Group UUID Attribute name"
: "Unikalny atrybut grupy"

, "User UUID Attribute name"
: "Unikalny atrybut użytkownika"

, "Readonly access"
: "Tylko do odczytu"

, "Save config and install"
: "Zapisz konfigurację i zainstaluj"

, "Save config"
: "Zapisz konfigurację"

, "Passwords don't match"
: "Hasła nie są takie same"

, "Should not be empty"
: "Nie może być puste"

, "File"
: "Plik"

, "Setup Authentication"
: "Konfiguruj uwierzytelnianie"

, "Username"
: "Użytkownik"

, "Database"
: "Baza danych"

, "User"
: "Użytkownik"

, "Prefix"
: "Przedrostek"

, "Logging"
: "Logi"

, "Filename"
: "Zapisuj do pliku"

, "Priority"
: "Tryb zapisu"

, "Caching"
: "Włącz pamięć podręczną"

, "Lifetime (seconds)"
: "Czas życia (sekundy)"

, "Path"
: "Ścieżka"

, "Queue"
: "Kolejka"

, "Session"
: "Sesja"

, "Temporary files"
: "Pliki tymczasowe"

, "Temporary Files Path"
: "Ścieżka do plików tymczasowych"

, "Filestore directory"
: "Katalog plików"

, "Filestore Path"
: "Ścieżka do katalogu plików"

, "Addressbook Map panel"
: "Mapowanie książki adresowej"

, "Map panel"
: "Mapowanie"

, "disabled"
: "wyłączone"

, "enabled"
: "włączone"

, "Config file is not writable"
: "Brak uprawnień zapisu do pliku konfiguracyjnego"

, "Download config file"
: "Pobierz plik konfiguracyjny"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Standard IMAP"
: "IMAP"

, "Standard SMTP"
: "SMTP"

, "Imap"
: "IMAP"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Użyj konta systemowego"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Administrator - Cyrus"

, "Cyrus Admin Password"
: "Hasło adminitratora - Cyrus"

, "Use proxy auth"
: ""

, "Smtp"
: "SMTP"

, "Authentication"
: "Uwierzytelnienie"

, "Login"
: "Login"

, "Plain"
: "Czysty tekst"

, "Primary Domain"
: "Domena główna"

, "Secondary Domains (comma separated)"
: "Poddomeny (oddzielone przecinkiem)"

, "Notifications service address"
: "Adres e-mail usługi powiadamiania"

, "Notification Username"
: "Przypomnienie nazwy użytkownika"

, "Notification Password"
: "Przypomnienie hasła"

, "Notifications local client (hostname or IP address)"
: "Powiadomienia, klient lokalny (nazwa hosta albo adres IP)"

, "SIEVE"
: "FILTR"

, "MySql Hostname"
: "Nazwa hosta dla MySQL"

, "MySql Database"
: "Baza danych MySQL"

, "MySql User"
: "Użytkownik MySQL"

, "MySql Password"
: "Hasło dla MySQL"

, "MySql Port"
: "Port MySQL"

, "User or UID"
: "Użytkownik albo UID"

, "Group or GID"
: "Grupa albo GID"

, "Home Template"
: "Szablon strony domowej"

, "Password Scheme"
: "Schemat hasła"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SHAA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SHAA512"

, "PLAIN"
: "PLAIN"

, "Setup"
: ""

, "Application, Applications"
: [
  "Aplikacja"
 ,"aplikacje"
 ,"aplikacje"
 ,"aplikacje"

]
, "Terms and Conditions"
: "Warunki i postanowienia"

, "Setup Checks"
: "Testy konfiguracji"

, "Config Manager"
: "Konfigurator ustawień"

, "Authentication/Accounts"
: "Uwierzytelnienie / Konta"

, "Email"
: "E-mail"

, "Application Manager"
: "Konfigurator aplikacji"

, "I have read the license agreement and accept it"
: "Przeczytałem postanowienia licencji i je akceptuję"

, "License Agreement"
: "Warunki udzielenia licencji"

, "I have read the privacy agreement and accept it"
: "Przeczytałem postanowienia poufności i je akceptuję"

, "Privacy Agreement"
: "Postanowienia poufności"

, "Accept Terms and Conditions"
: "Akceptuję warunki i postanowienia."


, "Application"
: "Aplikacja"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
